@@ -38,38 +38,38 @@ def main():
     group_io.add_argument('--message', help='Plain text message.', metavar="TEXT", nargs="?", action=BlankTrue)
     group_io.add_argument('--input', help='Path to message file. (Alternative to `message` parameter.)', metavar="FILE")
     group_io.add_argument('--output',
-                        help='Path to file to be written to (else the contents is returned if ciphering or True if sending).',
-                        metavar="FILE")
+                          help='Path to file to be written to (else the contents is returned if ciphering or True if sending).',
+                          metavar="FILE")
 
     group_ciph = parser.add_argument_group("Ciphering")
     group_ciph.add_argument('--gpg', help='Home path to GNUPG rings else default ~/.gnupg is used.'
-                                      'Leave blank for prefer GPG over S/MIME.', nargs="?", action=BlankTrue, metavar="PATH")
+                                          'Leave blank for prefer GPG over S/MIME.', nargs="?", action=BlankTrue, metavar="PATH")
     group_ciph.add_argument('--smime', action="store_true", help='Leave blank for prefer S/MIME over GPG.')
     group_ciph.add_argument('--sign', help='R|Sign the message.'
-                                       '\n * "auto" for turning on signing if there is a key matching to the "from" header'
-                                       '\n * GPG: Blank for user default key or key ID/fingerprint.'
-                                       '\n * S/MIME: Key data.', nargs="?",
-                        action=BlankTrue, metavar="FINGERPRINT|CONTENTS")
+                                           '\n * "auto" for turning on signing if there is a key matching to the "from" header'
+                                           '\n * GPG: Blank for user default key or key ID/fingerprint.'
+                                           '\n * S/MIME: Key data.', nargs="?",
+                            action=BlankTrue, metavar="FINGERPRINT|CONTENTS")
     group_ciph.add_argument('--cert', help='S/MIME: Certificate contents if not included in the key.',
-                        action=BlankTrue, metavar="CONTENTS")
+                            action=BlankTrue, metavar="CONTENTS")
     group_ciph.add_argument('--passphrase', help='If signing key needs passphrase.')
     group_ciph.add_argument('--sign-path', help='Filename with the sender\'s private key. (Alternative to `sign` parameter.)',
-                        metavar="KEY-PATH")
+                            metavar="KEY-PATH")
     group_ciph.add_argument('--cert-path', help='S/MIME: Filename with the sender\'s S/MIME private cert'
-                                            ' if cert not included in the key. (Alternative to `cert` parameter.)',
-                        metavar="CERT-PATH")
+                                                ' if cert not included in the key. (Alternative to `cert` parameter.)',
+                            metavar="CERT-PATH")
 
     group_ciph.add_argument('--encrypt', help='R|* GPG:'
-                                          "\n  * Blank for user default key"
-                                          "\n  * key ID/fingerprint"
-                                          "\n  * Any attainable contents with the key to be signed with"
-                                          " (will be imported into keyring)"
-                                          "\n  * \"auto\" for turning on encrypting if there is a matching key for every recipient"
-                                          "\n* S/MIME any attainable contents with certificate to be encrypted with or their list",
-                        nargs="*", action=BlankTrue, metavar="GPG-KEY/SMIME-CERTIFICATE-CONTENTS")
+                                              "\n  * Blank for user default key"
+                                              "\n  * key ID/fingerprint"
+                                              "\n  * Any attainable contents with the key to be signed with"
+                                              " (will be imported into keyring)"
+                                              "\n  * \"auto\" for turning on encrypting if there is a matching key for every recipient"
+                                              "\n* S/MIME any attainable contents with certificate to be encrypted with or their list",
+                            nargs="*", action=BlankTrue, metavar="GPG-KEY/SMIME-CERTIFICATE-CONTENTS")
     group_ciph.add_argument('--encrypt-path', help='Filename(s) with the recipient\'s public key.'
-                                               ' (Alternative to `encrypt` parameter.)',
-                        nargs="*", metavar="PATH")
+                                                   ' (Alternative to `encrypt` parameter.)',
+                            nargs="*", metavar="PATH")
     group_ciph.add_argument('--attach-key', help="Appending public key to the attachments when sending.", action="store_true")
 
     group_send = parser.add_argument_group("Sending")
@@ -78,24 +78,24 @@ def main():
     group_send.add_argument('--cc', help="E-mail or list", nargs="+", metavar="E-MAIL")
     group_send.add_argument('--bcc', help="E-mail or list", nargs="+", metavar="E-MAIL")
     group_send.add_argument('--reply-to', help="Header that states e-mail to be replied to. The field is not encrypted.",
-                        metavar="E-MAIL")
+                            metavar="E-MAIL")
     group_send.add_argument('-f', '--from', help="Alias of --sender", metavar="E-MAIL")
     group_send.add_argument('--sender', help="E-mail – needed to choose our key if encrypting", metavar="E-MAIL")
     group_send.add_argument('--no-sender', action="store_true",
-                        help="We explicitly say we do not want to decipher later if encrypting.")
+                            help="We explicitly say we do not want to decipher later if encrypting.")
     group_send.add_argument('-a', '--attachment',
-                        help="Path to the attachment, followed by optional file name to be used and/or mimetype."
-                             " This parameter may be used multiple times.",
-                        nargs="+", action="append")
+                            help="Path to the attachment, followed by optional file name to be used and/or mimetype."
+                                 " This parameter may be used multiple times.",
+                            nargs="+", action="append")
     group_send.add_argument('--header',
-                        help="Any e-mail header in the form `name value`. Flag may be used multiple times.",
-                        nargs=2, action="append", metavar=("NAME", "VALUE"))
+                            help="Any e-mail header in the form `name value`. Flag may be used multiple times.",
+                            nargs=2, action="append", metavar=("NAME", "VALUE"))
     group_send.add_argument('--mime', help="Set contents mime subtype: 'html' (default) or 'plain' for plain text",
-                        metavar="SUBTYPE")
+                            metavar="SUBTYPE")
     group_send.add_argument('--smtp', help="SMTP server. List `host, [port, [username, password, [security]]]` or dict.\n"
-                                       "Ex: '--smtp {\"host\": \"localhost\", \"port\": 25}'."
-                                       " Security may be explicitly set to 'starttls', 'tls' or automatically determined by port.",
-                        nargs="*", action=BlankTrue, metavar=("HOST", "PORT"))
+                                           "Ex: '--smtp {\"host\": \"localhost\", \"port\": 25}'."
+                                           " Security may be explicitly set to 'starttls', 'tls' or automatically determined by port.",
+                            nargs="*", action=BlankTrue, metavar=("HOST", "PORT"))
     group_send.add_argument('--send', help="Send e-mail. Blank to send now.", nargs="?", action=BlankTrue)
 
     group_supp = parser.add_argument_group("Supportive")
@@ -134,7 +134,7 @@ def main():
 
     # we explicitly say we do not want to decipher later if encrypting
     if args["no_sender"]:
-        args["sender"] = False
+        args["from_"] = False
     del args["no_sender"]
 
     # user is saying that encryption key has been already imported
